@@ -6,14 +6,12 @@
 #include "KinoSearch/Store/InStream.h"
 #include "KinoSearch/Store/OutStream.h"
 
-/* Extract a document's compressed TermVector data into ( term_text =>
- * compressed positional data ) pairs.
- */
+// Extract a document's compressed TermVector data into ( term_text =>
+// compressed positional data ) pairs.
 static Hash*
 S_extract_tv_cache(ByteBuf *field_buf);
 
-/* Pull a TermVector object out from compressed positional data.
- */
+// Pull a TermVector object out from compressed positional data.
 static TermVector*
 S_extract_tv_from_tv_buf(const CharBuf *field, const CharBuf *term_text, 
                          ByteBuf *tv_buf);
@@ -83,19 +81,19 @@ DocVec_term_vector(DocVector *self, const CharBuf *field,
     ByteBuf *tv_buf;
     Hash *field_vector = (Hash*)Hash_Fetch(self->field_vectors, (Obj*)field);
     
-    /* If no cache hit, try to fill cache. */
+    // If no cache hit, try to fill cache. 
     if (field_vector == NULL) {
         ByteBuf *field_buf 
             = (ByteBuf*)Hash_Fetch(self->field_bufs, (Obj*)field);
 
-        /* Bail if there's no content or the field isn't highlightable. */
+        // Bail if there's no content or the field isn't highlightable. 
         if (field_buf == NULL) return NULL;
 
         field_vector = S_extract_tv_cache(field_buf);
         Hash_Store(self->field_vectors, (Obj*)field, (Obj*)field_vector);
     }
 
-    /* Get a buf for the term text or bail. */
+    // Get a buf for the term text or bail. 
     tv_buf = (ByteBuf*)Hash_Fetch(field_vector, (Obj*)term_text);
     if (tv_buf == NULL) 
         return NULL;
@@ -108,34 +106,34 @@ S_extract_tv_cache(ByteBuf *field_buf)
 {
     Hash          *tv_cache  = Hash_new(0);
     char          *tv_string = BB_Get_Buf(field_buf);
-    i32_t          num_terms = NumUtil_decode_c32(&tv_string);
+    int32_t        num_terms = NumUtil_decode_c32(&tv_string);
     CharBuf       *text      = CB_new(0);
-    i32_t          i;
+    int32_t        i;
     
-    /* Read the number of highlightable terms in the field. */
+    // Read the number of highlightable terms in the field. 
     for (i = 0; i < num_terms; i++) {
         char         *bookmark_ptr;
         size_t        overlap = NumUtil_decode_c32(&tv_string);
         size_t        len     = NumUtil_decode_c32(&tv_string);
-        i32_t         num_positions;
+        int32_t       num_positions;
 
-        /* Decompress the term text. */
+        // Decompress the term text. 
         CB_Set_Size(text, overlap);
         CB_Cat_Trusted_Str(text, tv_string, len);
         tv_string += len;
 
-        /* Get positions & offsets string. */
+        // Get positions & offsets string. 
         bookmark_ptr  = tv_string;
         num_positions = NumUtil_decode_c32(&tv_string);
         while(num_positions--) {
-            /* Leave nums compressed to save a little mem. */
+            // Leave nums compressed to save a little mem. 
             NumUtil_skip_cint(&tv_string);
             NumUtil_skip_cint(&tv_string);
             NumUtil_skip_cint(&tv_string);
         }
         len = tv_string - bookmark_ptr;
 
-        /* Store the $text => $posdata pair in the output hash. */
+        // Store the $text => $posdata pair in the output hash. 
         Hash_Store(tv_cache, (Obj*)text,
             (Obj*)BB_new_bytes(bookmark_ptr, len));
     }
@@ -151,20 +149,20 @@ S_extract_tv_from_tv_buf(const CharBuf *field, const CharBuf *term_text,
     TermVector *retval      = NULL;
     char       *posdata     = BB_Get_Buf(tv_buf);
     char       *posdata_end = posdata + BB_Get_Size(tv_buf);
-    i32_t      *positions   = NULL;
-    i32_t      *starts      = NULL;
-    i32_t      *ends        = NULL;
-    u32_t       num_pos     = 0;
-    u32_t       i;
+    int32_t    *positions   = NULL;
+    int32_t    *starts      = NULL;
+    int32_t    *ends        = NULL;
+    uint32_t    num_pos     = 0;
+    uint32_t    i;
 
     if (posdata != posdata_end) {
         num_pos   = NumUtil_decode_c32(&posdata);
-        positions = (i32_t*)MALLOCATE(num_pos * sizeof(i32_t));
-        starts    = (i32_t*)MALLOCATE(num_pos * sizeof(i32_t));
-        ends      = (i32_t*)MALLOCATE(num_pos * sizeof(i32_t));
+        positions = (int32_t*)MALLOCATE(num_pos * sizeof(int32_t));
+        starts    = (int32_t*)MALLOCATE(num_pos * sizeof(int32_t));
+        ends      = (int32_t*)MALLOCATE(num_pos * sizeof(int32_t));
     }
 
-    /* Expand C32s. */
+    // Expand C32s. 
     for (i = 0; i < num_pos; i++) {
         positions[i] = NumUtil_decode_c32(&posdata);
         starts[i]    = NumUtil_decode_c32(&posdata);
