@@ -7,9 +7,9 @@
 #include "KinoSearch/Index/PolyReader.h"
 #include "KinoSearch/Index/Posting/RawPosting.h"
 #include "KinoSearch/Index/Segment.h"
+#include "KinoSearch/Index/Similarity.h"
 #include "KinoSearch/Index/Snapshot.h"
 #include "KinoSearch/Plan/Schema.h"
-#include "KinoSearch/Search/Similarity.h"
 #include "KinoSearch/Store/InStream.h"
 
 Posting*
@@ -20,13 +20,13 @@ Post_init(Posting *self)
 }
 
 void
-Post_set_doc_id(Posting *self, i32_t doc_id) { self->doc_id = doc_id; }
-i32_t
+Post_set_doc_id(Posting *self, int32_t doc_id) { self->doc_id = doc_id; }
+int32_t
 Post_get_doc_id(Posting *self) { return self->doc_id; }
 
 PostingWriter*
 PostWriter_init(PostingWriter *self, Schema *schema, Snapshot *snapshot,
-                Segment *segment, PolyReader *polyreader, i32_t field_num)
+                Segment *segment, PolyReader *polyreader, int32_t field_num)
 {
     DataWriter_init((DataWriter*)self, schema, snapshot, segment,
         polyreader);
