@@ -153,11 +153,11 @@ SortFieldWriter_get_ord_width(SortFieldWriter *self) { return self->ord_width; }
 static Obj*
 S_find_unique_value(Hash *uniq_vals, Obj *val)
 {
-    int32_t  hash_code = Obj_Hash_Code(val);
-    Obj     *uniq_val  = Hash_Find_Key(uniq_vals, val, hash_code);
+    int32_t  hash_sum  = Obj_Hash_Sum(val);
+    Obj     *uniq_val  = Hash_Find_Key(uniq_vals, val, hash_sum);
     if (!uniq_val) { 
         Hash_Store(uniq_vals, val, INCREF(&EMPTY)); 
-        uniq_val = Hash_Find_Key(uniq_vals, val, hash_code);
+        uniq_val = Hash_Find_Key(uniq_vals, val, hash_sum);
     }
     return uniq_val;
 }
@@ -637,9 +637,7 @@ S_flip_run(SortFieldWriter *run, size_t sub_thresh, InStream *ord_in,
 
     // Open the temp files for reading.
     CharBuf *seg_name = Seg_Get_Name(run->segment);
-    size_t   size     = ZCB_size() + CB_Get_Size(seg_name) + 100;
-    CharBuf *alias    = (CharBuf*)ZCB_newf(alloca(size), size, "");
-    CB_setf(alias, "%o/sort_ord_temp-%i64-to-%i64", seg_name, 
+    CharBuf *alias    = CB_newf("%o/sort_ord_temp-%i64-to-%i64", seg_name, 
         run->ord_start, run->ord_end);
     InStream *ord_in_dupe = InStream_Reopen(ord_in, alias,
         run->ord_start, run->ord_end - run->ord_start);
@@ -654,6 +652,7 @@ S_flip_run(SortFieldWriter *run, size_t sub_thresh, InStream *ord_in,
         run->dat_start, run->dat_end);
     InStream *dat_in_dupe = InStream_Reopen(dat_in, alias,
         run->dat_start, run->dat_end - run->dat_start);
+    DECREF(alias);
 
     // Get a SortCache.
     CharBuf *field = Seg_Field_Name(run->segment, run->field_num);
