@@ -20,7 +20,7 @@
 #include "KinoSearch/Util/MemoryPool.h"
 #include "KinoSearch/Util/SortUtils.h"
 
-i32_t SortWriter_current_file_format = 3;
+int32_t SortWriter_current_file_format = 3;
 
 static size_t default_mem_thresh = 0x400000; // 4 MB
 
@@ -36,10 +36,10 @@ SortWriter*
 SortWriter_init(SortWriter *self, Schema *schema, Snapshot *snapshot,
                 Segment *segment, PolyReader *polyreader)
 {
-    u32_t field_max = Schema_Num_Fields(schema) + 1;
+    uint32_t field_max = Schema_Num_Fields(schema) + 1;
     DataWriter_init((DataWriter*)self, schema, snapshot, segment, polyreader);
 
-    /* Init. */
+    // Init. 
     self->field_writers   = VA_new(field_max);
     self->counts          = Hash_new(0);
     self->null_ords       = Hash_new(0);
@@ -85,17 +85,25 @@ S_lazy_init_field_writer(SortWriter *self, int32_t field_num)
         if (!self->temp_ord_out) {
             Folder  *folder   = self->folder;
             CharBuf *seg_name = Seg_Get_Name(self->segment);
-            size_t   size     = ZCB_size() + CB_Get_Size(seg_name) + 50;
-            CharBuf *path     = (CharBuf*)ZCB_newf(alloca(size), size, "");
-            CB_setf(path, "%o/sort_ord_temp", seg_name);
+            CharBuf *path     = CB_newf("%o/sort_ord_temp", seg_name);
             self->temp_ord_out = Folder_Open_Out(folder, path);
-            if (!self->temp_ord_out) { RETHROW(INCREF(Err_get_error())); }
+            if (!self->temp_ord_out) { 
+                DECREF(path);
+                RETHROW(INCREF(Err_get_error())); 
+            }
             CB_setf(path, "%o/sort_ix_temp", seg_name);
             self->temp_ix_out = Folder_Open_Out(folder, path);
-            if (!self->temp_ix_out) { RETHROW(INCREF(Err_get_error())); }
+            if (!self->temp_ix_out) { 
+                DECREF(path);
+                RETHROW(INCREF(Err_get_error())); 
+            }
             CB_setf(path, "%o/sort_dat_temp", seg_name);
             self->temp_dat_out = Folder_Open_Out(folder, path);
-            if (!self->temp_dat_out) { RETHROW(INCREF(Err_get_error())); }
+            if (!self->temp_dat_out) { 
+                DECREF(path);
+                RETHROW(INCREF(Err_get_error()));
+            }
+            DECREF(path);
         }
 
         CharBuf *field = Seg_Field_Name(self->segment, field_num);
@@ -110,11 +118,11 @@ S_lazy_init_field_writer(SortWriter *self, int32_t field_num)
 
 void
 SortWriter_add_inverted_doc(SortWriter *self, Inverter *inverter, 
-                            i32_t doc_id)
+                            int32_t doc_id)
 {
-    i32_t field_num;
+    int32_t field_num;
 
-    Inverter_Iter_Init(inverter);
+    Inverter_Iterate(inverter);
     while (0 != (field_num = Inverter_Next(inverter))) {
         FieldType *type = Inverter_Get_Type(inverter);
         if (FType_Sortable(type)) {
@@ -125,9 +133,8 @@ SortWriter_add_inverted_doc(SortWriter *self, Inverter *inverter,
         }
     }
 
-    /* If our SortFieldWriters have collectively passed the memory threshold,
-     * flush all of them, then release all unique values with a single action.
-     * */
+    // If our SortFieldWriters have collectively passed the memory threshold,
+    // flush all of them, then release all unique values with a single action.
     if (MemPool_Get_Consumed(self->mem_pool) > self->mem_thresh) {
         for (uint32_t i = 0; i < VA_Get_Size(self->field_writers); i++) {
             SortFieldWriter *const field_writer 
@@ -144,7 +151,7 @@ SortWriter_add_segment(SortWriter *self, SegReader *reader, I32Array *doc_map)
 {
     VArray *fields  = Schema_All_Fields(self->schema);
 
-    /* Proceed field-at-a-time, rather than doc-at-a-time. */
+    // Proceed field-at-a-time, rather than doc-at-a-time. 
     for (uint32_t i = 0, max = VA_Get_Size(fields); i < max; i++) {
         CharBuf *field = (CharBuf*)VA_Fetch(fields, i);
         SortReader *sort_reader = (SortReader*)SegReader_Fetch(reader, 
@@ -211,21 +218,20 @@ SortWriter_finish(SortWriter *self)
     }
     VA_Clear(field_writers);
 
-    /* Store metadata. */
+    // Store metadata. 
     Seg_Store_Metadata_Str(self->segment, "sort", 4,
         (Obj*)SortWriter_Metadata(self));
 
     // Clean up. 
     Folder  *folder   = self->folder;
     CharBuf *seg_name = Seg_Get_Name(self->segment);
-    size_t   size     = ZCB_size() + CB_Get_Size(seg_name) + 40;
-    CharBuf *path     = (CharBuf*)ZCB_newf(alloca(size), size, "");
-    CB_setf(path, "%o/sort_ord_temp", seg_name);
+    CharBuf *path     = CB_newf("%o/sort_ord_temp", seg_name);
     Folder_Delete(folder, path);
     CB_setf(path, "%o/sort_ix_temp", seg_name);
     Folder_Delete(folder, path);
     CB_setf(path, "%o/sort_dat_temp", seg_name);
     Folder_Delete(folder, path);
+    DECREF(path);
 }
 
 Hash*
@@ -238,7 +244,7 @@ SortWriter_metadata(SortWriter *self)
     return metadata;
 }
 
-i32_t
+int32_t
 SortWriter_format(SortWriter *self)
 {
     UNUSED_VAR(self);
