@@ -16,11 +16,6 @@
   #include <unistd.h>
 #endif
 
-// For CreateHardLink. 
-#ifdef CHY_HAS_WINDOWS_H
-  #include <windows.h>
-#endif
-
 // For mkdir, rmdir. 
 #ifdef CHY_HAS_DIRECT_H
   #include <direct.h>
@@ -35,15 +30,9 @@
 #include "KinoSearch/Store/OutStream.h"
 #include "KinoSearch/Util/IndexFileNames.h"
 
-// Return a ZombieCharBuf (cast to CharBuf) containing a platform-specific
-// absolute filepath.
+// Return a CharBuf containing a platform-specific absolute filepath.
 static CharBuf*
-S_fullpath(FSFolder *self, const CharBuf *path, void *allocation, 
-           size_t alloc_size);
-#define FULLPATH(self, _path) \
-    S_fullpath(self, _path, alloca( \
-        ZCB_size() + CB_Get_Size(self->path) + CB_Get_Size(_path) + 10), \
-        ZCB_size() + CB_Get_Size(self->path) + CB_Get_Size(_path) + 10)
+S_fullpath(FSFolder *self, const CharBuf *path);
 
 // Return true if the supplied path is a directory. 
 static bool_t
@@ -57,6 +46,10 @@ S_create_dir(const CharBuf *path);
 bool_t
 S_is_local_entry(const CharBuf *path);
 
+// Create a hard link.
+bool_t
+S_hard_link(CharBuf *from_path, CharBuf *to_path);
+
 FSFolder*
 FSFolder_new(const CharBuf *path) 
 {
@@ -92,22 +85,20 @@ FSFolder_check(FSFolder *self)
 FileHandle*
 FSFolder_local_open_filehandle(FSFolder *self, const CharBuf *name, uint32_t flags)
 {
-    CharBuf      *fullpath = FULLPATH(self, name);
+    CharBuf      *fullpath = S_fullpath(self, name);
     FSFileHandle *fh = FSFH_open(fullpath, flags);
-    if (!fh) {
-        ERR_ADD_FRAME(Err_get_error());
-    }
+    if (!fh) { ERR_ADD_FRAME(Err_get_error()); }
+    DECREF(fullpath);
     return (FileHandle*)fh;
 }
 
 bool_t
 FSFolder_local_mkdir(FSFolder *self, const CharBuf *name)
 {
-    CharBuf *dir = FULLPATH(self, name);
+    CharBuf *dir = S_fullpath(self, name);
     bool_t result = S_create_dir(dir);
-    if (!result) {
-        ERR_ADD_FRAME(Err_get_error());
-    }
+    if (!result) { ERR_ADD_FRAME(Err_get_error()); }
+    DECREF(dir);
     return result;
 }
 
@@ -130,10 +121,11 @@ FSFolder_local_exists(FSFolder *self, const CharBuf *name)
     }
     else {
         struct stat stat_buf;
-        CharBuf *fullpath = FULLPATH(self, name);
+        CharBuf *fullpath = S_fullpath(self, name);
         bool_t retval = false;
         if (stat((char*)CB_Get_Ptr8(fullpath), &stat_buf) != -1)
             retval = true;
+        DECREF(fullpath);
         return retval;
     }
 }
@@ -147,8 +139,9 @@ FSFolder_local_is_directory(FSFolder *self, const CharBuf *name)
         return true; 
     }
     else {
-        CharBuf *fullpath = FULLPATH(self, name);
+        CharBuf *fullpath = S_fullpath(self, name);
         bool_t result = S_dir_ok(fullpath);
+        DECREF(fullpath);
         return result;
     }
 }
@@ -156,14 +149,16 @@ FSFolder_local_is_directory(FSFolder *self, const CharBuf *name)
 bool_t
 FSFolder_rename(FSFolder *self, const CharBuf* from, const CharBuf *to)
 {
-    CharBuf *from_path = FULLPATH(self, from);
-    CharBuf *to_path   = FULLPATH(self, to);
+    CharBuf *from_path = S_fullpath(self, from);
+    CharBuf *to_path   = S_fullpath(self, to);
     bool_t   retval    = !rename((char*)CB_Get_Ptr8(from_path), 
         (char*)CB_Get_Ptr8(to_path));
     if (!retval) {
         Err_set_error(Err_new(CB_newf("rename from '%o' to '%o' failed: %s",
             from_path, to_path, strerror(errno))));
     }
+    DECREF(from_path);
+    DECREF(to_path);
     return retval;
 }
 
@@ -171,38 +166,18 @@ bool_t
 FSFolder_hard_link(FSFolder *self, const CharBuf *from, 
                    const CharBuf *to)
 {
-    CharBuf *from_path = FULLPATH(self, from);
-    CharBuf *to_path   = FULLPATH(self, to);
-    char    *from8     = (char*)CB_Get_Ptr8(from_path);
-    char    *to8       = (char*)CB_Get_Ptr8(to_path);
-#ifdef CHY_HAS_UNISTD_H
-    bool_t retval;
-    if (-1 == link(from8, to8)) {
-        retval = false;
-        Err_set_error(Err_new(CB_newf(
-            "hard link for new file '%o' from '%o' failed: %s",
-                to_path, from_path, strerror(errno))));
-    }
-    else {
-        retval = true;
-    }
-#elif defined(CHY_HAS_WINDOWS_H)
-    bool_t retval = !!CreateHardLink(to8, from8, NULL);
-    if (!retval) {
-        char *win_error = Err_win_error();
-        Err_set_error(Err_new(CB_newf(
-            "CreateHardLink for new file '%o' from '%o' failed: %s",
-                to_path, from_path, win_error)));
-        FREEMEM(win_error);
-    }
-#endif
+    CharBuf *from_path = S_fullpath(self, from);
+    CharBuf *to_path   = S_fullpath(self, to);
+    bool_t   retval    = S_hard_link(from_path, to_path);
+    DECREF(from_path);
+    DECREF(to_path);
     return retval;
 }
 
 bool_t
 FSFolder_local_delete(FSFolder *self, const CharBuf *name)
 {
-    CharBuf *fullpath = FULLPATH(self, name);
+    CharBuf *fullpath = S_fullpath(self, name);
     char    *path_ptr = (char*)CB_Get_Ptr8(fullpath);
 #ifdef CHY_REMOVE_ZAPS_DIRS
     bool_t result = !remove(path_ptr);
@@ -210,6 +185,7 @@ FSFolder_local_delete(FSFolder *self, const CharBuf *name)
     bool_t result = !rmdir(path_ptr) || !remove(path_ptr); 
 #endif
     DECREF(Hash_Delete(self->entries, (Obj*)name));
+    DECREF(fullpath);
     return result;
 }
 
@@ -243,37 +219,34 @@ FSFolder_local_find_folder(FSFolder *self, const CharBuf *name)
         }
     }
 
-    {
-        CharBuf *fullpath = FULLPATH(self, name);
-        if (S_dir_ok(fullpath)) {
-            subfolder = (Folder*)FSFolder_new(fullpath);
-            if (!subfolder) {
-                THROW(ERR, "Failed to open FSFolder at '%o'", fullpath);
-            }
-            // Try to open a CompoundFileReader. On failure, just use the
-            // existing folder.
-            CharBuf *cfmeta_file = (CharBuf*)ZCB_WRAP_STR("cfmeta.json", 11);
-            if (Folder_Local_Exists(subfolder, cfmeta_file)) {
-                CompoundFileReader *cf_reader = CFReader_open(subfolder);
-                if (cf_reader) {
-                    DECREF(subfolder);
-                    subfolder = (Folder*)cf_reader;
-                }
-            }
-            Hash_Store(self->entries, (Obj*)name, (Obj*)subfolder);
-            return subfolder;
+    CharBuf *fullpath = S_fullpath(self, name);
+    if (S_dir_ok(fullpath)) {
+        subfolder = (Folder*)FSFolder_new(fullpath);
+        if (!subfolder) {
+            DECREF(fullpath);
+            THROW(ERR, "Failed to open FSFolder at '%o'", fullpath);
         }
+        // Try to open a CompoundFileReader. On failure, just use the
+        // existing folder.
+        CharBuf *cfmeta_file = (CharBuf*)ZCB_WRAP_STR("cfmeta.json", 11);
+        if (Folder_Local_Exists(subfolder, cfmeta_file)) {
+            CompoundFileReader *cf_reader = CFReader_open(subfolder);
+            if (cf_reader) {
+                DECREF(subfolder);
+                subfolder = (Folder*)cf_reader;
+            }
+        }
+        Hash_Store(self->entries, (Obj*)name, (Obj*)subfolder);
     }
+    DECREF(fullpath);
 
-    return NULL;
+    return subfolder;
 }
 
 static CharBuf*
-S_fullpath(FSFolder *self, const CharBuf *path, void *allocation, 
-           size_t alloc_size)
+S_fullpath(FSFolder *self, const CharBuf *path)
 {
-    CharBuf *fullpath = (CharBuf*)ZCB_newf(allocation, alloc_size, "%o%s%o",
-        self->path, DIR_SEP, path);
+    CharBuf *fullpath = CB_newf("%o%s%o", self->path, DIR_SEP, path);
     if (DIR_SEP[0] != '/') {
         CB_Swap_Chars(fullpath, '/', DIR_SEP[0]);
     }
@@ -312,6 +285,62 @@ S_is_local_entry(const CharBuf *path)
     return true;
 }
 
+/***************************************************************************/
+
+#ifdef CHY_HAS_UNISTD_H
+
+bool_t
+S_hard_link(CharBuf *from_path, CharBuf *to_path)
+{
+    char *from8 = (char*)CB_Get_Ptr8(from_path);
+    char *to8   = (char*)CB_Get_Ptr8(to_path);
+
+    if (-1 == link(from8, to8)) {
+        Err_set_error(Err_new(CB_newf(
+            "hard link for new file '%o' from '%o' failed: %s",
+                to_path, from_path, strerror(errno))));
+        return false;
+    }
+    else {
+        return true;
+    }
+}
+
+#elif defined(CHY_HAS_WINDOWS_H)
+
+// Windows.h defines INCREF and DECREF, so we include it only at the end of
+// this file and undef those symbols.
+#undef INCREF
+#undef DECREF
+
+// For CreateHardLink. 
+#ifdef CHY_HAS_WINDOWS_H
+  #include <windows.h>
+#endif
+
+#include <windows.h>
+
+bool_t
+S_hard_link(CharBuf *from_path, CharBuf *to_path)
+{
+    char *from8 = (char*)CB_Get_Ptr8(from_path);
+    char *to8   = (char*)CB_Get_Ptr8(to_path);
+
+    if (CreateHardLink(to8, from8, NULL)) {
+        return true;
+    }
+    else {
+        char *win_error = Err_win_error();
+        Err_set_error(Err_new(CB_newf(
+            "CreateHardLink for new file '%o' from '%o' failed: %s",
+                to_path, from_path, win_error)));
+        FREEMEM(win_error);
+        return false;
+    }
+}
+
+#endif /* CHY_HAS_UNISTD_H vs. CHY_HAS_WINDOWS_H */
+
 /* Copyright 2006-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
