@@ -10,11 +10,9 @@
 #include "KinoSearch/Store/Folder.h"
 #include "KinoSearch/Store/OutStream.h"
 
-static ZombieCharBuf lock_dir_name = ZCB_LITERAL("locks");
-
 SharedLock*
 ShLock_new(Folder *folder, const CharBuf *name, const CharBuf *host, 
-           i32_t timeout, i32_t interval)
+           int32_t timeout, int32_t interval)
 {
     SharedLock *self = (SharedLock*)VTable_Make_Obj(SHAREDLOCK);
     return ShLock_init(self, folder, name, host, timeout, interval);
@@ -22,11 +20,11 @@ ShLock_new(Folder *folder, const CharBuf *name, const CharBuf *host,
 
 SharedLock*
 ShLock_init(SharedLock *self, Folder *folder, const CharBuf *name, 
-            const CharBuf *host, i32_t timeout, i32_t interval)
+            const CharBuf *host, int32_t timeout, int32_t interval)
 {
     LFLock_init((LockFileLock*)self, folder, name, host, timeout, interval);
 
-    /* Override. */
+    // Override. 
     DECREF(self->lock_path);
     self->lock_path = (CharBuf*)INCREF(&EMPTY);
 
@@ -39,15 +37,17 @@ ShLock_shared(SharedLock *self) { UNUSED_VAR(self); return true; }
 bool_t
 ShLock_request(SharedLock *self)
 {
-    u32_t i = 0;
+    uint32_t i = 0;
     ShLock_request_t super_request 
         = (ShLock_request_t)SUPER_METHOD(SHAREDLOCK, ShLock, Request);
 
-    /* EMPTY lock_path indicates whether this particular instance is locked. */
+    // EMPTY lock_path indicates whether this particular instance is locked. 
     if (   self->lock_path != (CharBuf*)&EMPTY 
         && Folder_Exists(self->folder, self->lock_path)
     ) {
-        /* Don't allow double obtain. */
+        // Don't allow double obtain. 
+        Err_set_error((Err*)LockErr_new(CB_newf(
+            "Lock already obtained via '%o'", self->lock_path)));
         return false;
     }
 
@@ -57,7 +57,9 @@ ShLock_request(SharedLock *self)
         CB_setf(self->lock_path, "locks/%o-%u32.lock", self->name, ++i);
     } while ( Folder_Exists(self->folder, self->lock_path) );
 
-    return super_request(self);
+    bool_t success = super_request(self);
+    if (!success) { ERR_ADD_FRAME(Err_get_error()); }
+    return success;
 }
 
 void
@@ -68,7 +70,7 @@ ShLock_release(SharedLock *self)
             = (ShLock_release_t)SUPER_METHOD(SHAREDLOCK, ShLock, Release);
         super_release(self);
 
-        /* Empty out lock_path. */
+        // Empty out lock_path. 
         DECREF(self->lock_path);
         self->lock_path = (CharBuf*)INCREF(&EMPTY);
     }
@@ -81,9 +83,10 @@ ShLock_clear_stale(SharedLock *self)
     DirHandle *dh;
     CharBuf   *entry;
     CharBuf   *candidate = NULL;
+    CharBuf   *lock_dir_name = (CharBuf*)ZCB_WRAP_STR("locks", 5);
 
-    if (Folder_Find_Folder(self->folder, (CharBuf*)&lock_dir_name)) {
-        dh = Folder_Open_Dir(self->folder, (CharBuf*)&lock_dir_name);
+    if (Folder_Find_Folder(self->folder, lock_dir_name)) {
+        dh = Folder_Open_Dir(self->folder, lock_dir_name);
         if (!dh) { RETHROW(INCREF(Err_get_error())); }
         entry = DH_Get_Entry(dh);
     }
@@ -91,13 +94,13 @@ ShLock_clear_stale(SharedLock *self)
         return;
     }
 
-    /* Take a stab at any file that begins with our lock name. */
+    // Take a stab at any file that begins with our lock name. 
     while (DH_Next(dh)) {
         if (   CB_Starts_With(entry, self->name)
             && CB_Ends_With_Str(entry, ".lock", 5)
         ) {
             candidate = candidate ? candidate : CB_new(0);
-            CB_setf(candidate, "%o/%o", &lock_dir_name, entry);
+            CB_setf(candidate, "%o/%o", lock_dir_name, entry);
             ShLock_Maybe_Delete_File(self, candidate, false, true);
         }
     }
@@ -112,8 +115,9 @@ ShLock_is_locked(SharedLock *self)
     DirHandle *dh;
     CharBuf   *entry;
 
-    if (Folder_Find_Folder(self->folder, (CharBuf*)&lock_dir_name)) {
-        dh = Folder_Open_Dir(self->folder, (CharBuf*)&lock_dir_name);
+    CharBuf *lock_dir_name = (CharBuf*)ZCB_WRAP_STR("locks", 5);
+    if (Folder_Find_Folder(self->folder, lock_dir_name)) {
+        dh = Folder_Open_Dir(self->folder, lock_dir_name);
         if (!dh) { RETHROW(INCREF(Err_get_error())); }
         entry = DH_Get_Entry(dh);
     }
@@ -122,20 +126,18 @@ ShLock_is_locked(SharedLock *self)
     }
     
     while (DH_Next(dh)) {
-        /* Translation: 
-         *   $locked = 1 if $entry =~ /^\Q$name-\d+\.lock$/ 
-         */
+        // Translation:  $locked = 1 if $entry =~ /^\Q$name-\d+\.lock$/ 
         if (   CB_Starts_With(entry, self->name)
             && CB_Ends_With_Str(entry, ".lock", 5)
         ) {
-            ZombieCharBuf scratch = ZCB_make(entry);
-            ZCB_Chop(&scratch, sizeof(".lock") - 1);
-            while(isdigit(ZCB_Code_Point_From(&scratch, 1))) {
-                ZCB_Chop(&scratch, 1);
+            ZombieCharBuf *scratch = ZCB_WRAP(entry);
+            ZCB_Chop(scratch, sizeof(".lock") - 1);
+            while(isdigit(ZCB_Code_Point_From(scratch, 1))) {
+                ZCB_Chop(scratch, 1);
             }
-            if (ZCB_Code_Point_From(&scratch, 1) == '-') {
-                ZCB_Chop(&scratch, 1);
-                if (ZCB_Equals(&scratch, (Obj*)self->name)) {
+            if (ZCB_Code_Point_From(scratch, 1) == '-') {
+                ZCB_Chop(scratch, 1);
+                if (ZCB_Equals(scratch, (Obj*)self->name)) {
                     DECREF(dh);
                     return true;
                 }
