@@ -17,11 +17,11 @@ S_no_op_method(const void *vself)
 static FileHandle*
 S_new_filehandle()
 {
-    static ZombieCharBuf klass = ZCB_LITERAL("TestFileHandle");
+    ZombieCharBuf *klass = ZCB_WRAP_STR("TestFileHandle", 14);
     FileHandle *fh;
-    VTable *vtable = VTable_fetch_vtable((CharBuf*)&klass);
+    VTable *vtable = VTable_fetch_vtable((CharBuf*)klass);
     if (!vtable) {
-        vtable = VTable_singleton((CharBuf*)&klass, FILEHANDLE);
+        vtable = VTable_singleton((CharBuf*)klass, FILEHANDLE);
     }   
     VTable_Override(vtable, S_no_op_method, Kino_FH_Close_OFFSET);
     fh = (FileHandle*)VTable_Make_Obj(vtable);
@@ -33,13 +33,13 @@ TestFH_run_tests()
 {
     TestBatch     *batch  = TestBatch_new(2);
     FileHandle    *fh     = S_new_filehandle();
-    ZombieCharBuf  foo    = ZCB_LITERAL("foo");
+    ZombieCharBuf *foo    = ZCB_WRAP_STR("foo", 3);
 
     TestBatch_Plan(batch);
 
-    ASSERT_TRUE(batch, CB_Equals_Str(FH_Get_Path(fh), "", 0), "Get_Path");
-    FH_Set_Path(fh, (CharBuf*)&foo);
-    ASSERT_TRUE(batch, CB_Equals(FH_Get_Path(fh), (Obj*)&foo), "Set_Path");
+    TEST_TRUE(batch, CB_Equals_Str(FH_Get_Path(fh), "", 0), "Get_Path");
+    FH_Set_Path(fh, (CharBuf*)foo);
+    TEST_TRUE(batch, CB_Equals(FH_Get_Path(fh), (Obj*)foo), "Set_Path");
 
     DECREF(fh);
     DECREF(batch);
