@@ -1,3 +1,4 @@
+package KinoSearch::Store::Folder;
 use KinoSearch;
 
 1;
@@ -6,7 +7,7 @@ __END__
 
 __BINDING__
 
-Boilerplater::Binding::Perl::Class->register(
+Clownfish::Binding::Perl::Class->register(
     parcel       => "KinoSearch",
     class_name   => "KinoSearch::Store::Folder",
     bind_methods => [
@@ -14,12 +15,11 @@ Boilerplater::Binding::Perl::Class->register(
             Open_Out
             Open_In
             MkDir
-            List
+            List_R
             Exists
             Rename
             Hard_Link
             Delete
-            Finish_Segment
             Slurp_File
             Close
             Get_Path
@@ -31,7 +31,7 @@ Boilerplater::Binding::Perl::Class->register(
 
 __COPYRIGHT__
 
-Copyright 2005-2009 Marvin Humphrey
+Copyright 2005-2010 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
