@@ -9,16 +9,15 @@
 #include "KinoSearch/Util/Memory.h"
 
 static SV*
-S_do_callback_sv(void *vobj, char *method, chy_u32_t num_args, va_list args);
+S_do_callback_sv(void *vobj, char *method, uint32_t num_args, va_list args);
 
-/* Convert all arguments to Perl and place them on the Perl stack. 
- */
+// Convert all arguments to Perl and place them on the Perl stack. 
 static CHY_INLINE void
-SI_push_args(void *vobj, va_list args, chy_u32_t num_args)
+SI_push_args(void *vobj, va_list args, uint32_t num_args)
 {
     kino_Obj *obj = (kino_Obj*)vobj;
     SV *invoker;
-    chy_u32_t i;
+    uint32_t i;
     dSP;
 
     uint32_t stack_slots_needed = num_args < 2
@@ -28,7 +27,7 @@ SI_push_args(void *vobj, va_list args, chy_u32_t num_args)
     
     if (Kino_Obj_Is_A(obj, KINO_VTABLE)) {
         kino_VTable *vtable = (kino_VTable*)obj;
-        /* TODO: Creating a new class name SV every time is wasteful. */
+        // TODO: Creating a new class name SV every time is wasteful. 
         invoker = XSBind_cb_to_sv(Kino_VTable_Get_Name(vtable));
     }
     else {
@@ -41,31 +40,31 @@ SI_push_args(void *vobj, va_list args, chy_u32_t num_args)
     PUSHs( sv_2mortal(invoker) );
 
     for (i = 0; i < num_args; i++) {
-        chy_u32_t arg_type = va_arg(args, chy_u32_t);
+        uint32_t arg_type = va_arg(args, uint32_t);
         char *label = va_arg(args, char*);
         if (num_args > 1) {
             PUSHs( sv_2mortal( newSVpvn(label, strlen(label)) ) );
         }
         switch (arg_type & KINO_HOST_ARGTYPE_MASK) {
         case KINO_HOST_ARGTYPE_I32: {
-                chy_i32_t value = va_arg(args, chy_i32_t);
+                int32_t value = va_arg(args, int32_t);
                 PUSHs( sv_2mortal( newSViv(value) ) );
             }
             break;
         case KINO_HOST_ARGTYPE_I64: {
-                chy_i64_t value = va_arg(args, chy_i64_t);
+                int64_t value = va_arg(args, int64_t);
                 if (sizeof(IV) == 8) {
                     PUSHs( sv_2mortal( newSViv((IV)value) ) );
                 }
                 else {
-                    /* lossy */
+                    // lossy 
                     PUSHs( sv_2mortal( newSVnv((double)value) ) );
                 }
             }
             break;
         case KINO_HOST_ARGTYPE_F32:
         case KINO_HOST_ARGTYPE_F64: {
-                /* Floats are promoted to doubles by variadic calling. */
+                // Floats are promoted to doubles by variadic calling. 
                 double value = va_arg(args, double);
                 PUSHs( sv_2mortal( newSVnv(value) ) );
             }
@@ -92,7 +91,7 @@ SI_push_args(void *vobj, va_list args, chy_u32_t num_args)
 }
 
 void
-kino_Host_callback(void *vobj, char *method, chy_u32_t num_args, ...) 
+kino_Host_callback(void *vobj, char *method, uint32_t num_args, ...) 
 {
     va_list args;
     
@@ -104,35 +103,35 @@ kino_Host_callback(void *vobj, char *method, chy_u32_t num_args, ...)
         int count = call_method(method, G_VOID|G_DISCARD);
         if (count != 0) {
             KINO_THROW(KINO_ERR, "callback '%s' returned too many values: %i32", 
-                method, (chy_i32_t)count);
+                method, (int32_t)count);
         }
         FREETMPS;
         LEAVE;
     }
 }
 
-chy_i64_t
-kino_Host_callback_i64(void *vobj, char *method, chy_u32_t num_args, ...) 
+int64_t
+kino_Host_callback_i64(void *vobj, char *method, uint32_t num_args, ...) 
 {
     va_list args;
     SV *return_sv;
-    chy_i64_t retval;
+    int64_t retval;
 
     va_start(args, num_args);
     return_sv = S_do_callback_sv(vobj, method, num_args, args);
     va_end(args);
     if (sizeof(IV) == 8) {
-        retval = (chy_i64_t)SvIV(return_sv);
+        retval = (int64_t)SvIV(return_sv);
     }
     else {
         if (SvIOK(return_sv)) {
-            /* It's already no more than 32 bits, so don't convert. */
+            // It's already no more than 32 bits, so don't convert. 
             retval = SvIV(return_sv);
         }
         else {
-            /* Maybe lossy. */
+            // Maybe lossy. 
             double temp = SvNV(return_sv);
-            retval = (chy_i64_t)temp;
+            retval = (int64_t)temp;
         }
     }
 
@@ -143,7 +142,7 @@ kino_Host_callback_i64(void *vobj, char *method, chy_u32_t num_args, ...)
 }
 
 double
-kino_Host_callback_f64(void *vobj, char *method, chy_u32_t num_args, ...) 
+kino_Host_callback_f64(void *vobj, char *method, uint32_t num_args, ...) 
 {
     va_list args;
     SV *return_sv;
@@ -162,7 +161,7 @@ kino_Host_callback_f64(void *vobj, char *method, chy_u32_t num_args, ...)
 
 kino_Obj*
 kino_Host_callback_obj(void *vobj, char *method, 
-                         chy_u32_t num_args, ...) 
+                         uint32_t num_args, ...) 
 {
     va_list args;
     SV *temp_retval;
@@ -181,7 +180,7 @@ kino_Host_callback_obj(void *vobj, char *method,
 }
 
 kino_CharBuf*
-kino_Host_callback_str(void *vobj, char *method, chy_u32_t num_args, ...)
+kino_Host_callback_str(void *vobj, char *method, uint32_t num_args, ...)
 {
     va_list args;
     SV *temp_retval;
@@ -191,7 +190,7 @@ kino_Host_callback_str(void *vobj, char *method, chy_u32_t num_args, ...)
     temp_retval = S_do_callback_sv(vobj, method, num_args, args);
     va_end(args);
 
-    /* Make a stringified copy. */
+    // Make a stringified copy. 
     if (temp_retval && XSBind_sv_defined(temp_retval)) {
         STRLEN len;
         char *ptr = SvPVutf8(temp_retval, len);
@@ -205,7 +204,7 @@ kino_Host_callback_str(void *vobj, char *method, chy_u32_t num_args, ...)
 }
 
 void*
-kino_Host_callback_host(void *vobj, char *method, chy_u32_t num_args, ...)
+kino_Host_callback_host(void *vobj, char *method, uint32_t num_args, ...)
 {
     va_list args;
     SV *retval;
@@ -222,7 +221,7 @@ kino_Host_callback_host(void *vobj, char *method, chy_u32_t num_args, ...)
 }
 
 static SV*
-S_do_callback_sv(void *vobj, char *method, chy_u32_t num_args, va_list args) 
+S_do_callback_sv(void *vobj, char *method, uint32_t num_args, va_list args) 
 {
     SV *return_val;
     SI_push_args(vobj, args, num_args);
@@ -231,7 +230,7 @@ S_do_callback_sv(void *vobj, char *method, chy_u32_t num_args, va_list args)
         dSP;
         if (num_returned != 1) {
             KINO_THROW(KINO_ERR, "Bad number of return vals from %s: %i32", method,
-                (chy_i32_t)num_returned);
+                (int32_t)num_returned);
         }
         return_val = POPs;
         PUTBACK;
